#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MINF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MINF_HPP_INCLUDED

#include <boost/simd/constant/include/constants/minf.hpp>

#endif
